@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Bakerloo;
 
-$Map::Tube::London::Line::Bakerloo::VERSION   = '0.49';
+$Map::Tube::London::Line::Bakerloo::VERSION   = '0.50';
 $Map::Tube::London::Line::Bakerloo::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Bakerloo - London Tube Map Bakerloo Line stations.
 
 =head1 VERSION
 
-Version 0.49
+Version 0.50
 
 =head1 DESCRIPTION
 
@@ -71,14 +71,14 @@ London Tube Map Bakerloo Line stations.
 
 =head1 MAP
 
-London Metro: L<Bakerloo|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Bakerloo.png>
-line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Tube Map: L<Bakerloo Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Bakerloo.png>
+map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
 <a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Bakerloo.png">
 <img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Bakerloo.png"
-     alt    = "London Metro: Bakerloo"
+     alt    = "London Tube Map: Bakerloo Line"
      width  = "500px"
      height = "500px"/>
 </a>
