@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Central;
 
-$Map::Tube::London::Line::Central::VERSION   = '0.49';
+$Map::Tube::London::Line::Central::VERSION   = '0.50';
 $Map::Tube::London::Line::Central::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Central - London Tube Map Central Line stations.
 
 =head1 VERSION
 
-Version 0.49
+Version 0.50
 
 =head1 DESCRIPTION
 
@@ -92,14 +92,14 @@ London Tube Map Central Line stations.
 
 =head1 MAP
 
-London Metro: L<Central|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png>
-line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Tube Map: L<Central Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png>
+map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
 <a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png">
 <img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Central.png"
-     alt    = "London Metro: Central"
+     alt    = "London Tube Map: Central Line"
      width  = "500px"
      height = "500px"/>
 </a>
