@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Circle;
 
-$Map::Tube::London::Line::Circle::VERSION   = '0.49';
+$Map::Tube::London::Line::Circle::VERSION   = '0.50';
 $Map::Tube::London::Line::Circle::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Circle - London Tube Map Circle Line stations.
 
 =head1 VERSION
 
-Version 0.49
+Version 0.50
 
 =head1 DESCRIPTION
 
@@ -101,14 +101,14 @@ London Tube Map Circle Line stations.
 
 =head1 MAP
 
-London Metro: L<Circle|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Circle.png>
-line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Tube Map: L<Circle Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Circle.png>
+map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
 <a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Circle.png">
 <img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Circle.png"
-     alt    = "London Metro: Circle"
+     alt    = "London Tube Map: Circle Line"
      width  = "500px"
      height = "500px"/>
 </a>
