@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::District;
 
-$Map::Tube::London::Line::District::VERSION   = '0.49';
+$Map::Tube::London::Line::District::VERSION   = '0.50';
 $Map::Tube::London::Line::District::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::District - London Tube Map District Line stations.
 
 =head1 VERSION
 
-Version 0.49
+Version 0.50
 
 =head1 DESCRIPTION
 
@@ -130,14 +130,14 @@ London Tube Map District Line stations.
 
 =head1 MAP
 
-London Metro: L<District|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/District.png>
-line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Tube Map: L<District Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/District.png>
+map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
 <a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/District.png">
 <img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/District.png"
-     alt    = "London Metro: District"
+     alt    = "London Tube Map: District Line"
      width  = "400px"
      height = "600px"/>
 </a>
