@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::HammersmithCity;
 
-$Map::Tube::London::Line::HammersmithCity::VERSION   = '0.49';
+$Map::Tube::London::Line::HammersmithCity::VERSION   = '0.50';
 $Map::Tube::London::Line::HammersmithCity::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::HammersmithCity - London Tube Map Hammersmith & City Li
 
 =head1 VERSION
 
-Version 0.49
+Version 0.50
 
 =head1 DESCRIPTION
 
@@ -87,14 +87,14 @@ London Tube Map Hammersmith & City Line stations.
 
 =head1 MAP
 
-London Metro: L<Hammersmith & City|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/HammersmithCity.png>
-line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Tube Map: L<Hammersmith & City Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/HammersmithCity.png>
+map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
 <a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/HammersmithCity.png">
 <img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/HammersmithCity.png"
-     alt    = "London Metro: Hammersmith & City"
+     alt    = "London Tube Map: Hammersmith & City Line"
      width  = "500px"
      height = "500px"/>
 </a>
