@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Jubilee;
 
-$Map::Tube::London::Line::Jubilee::VERSION   = '0.49';
+$Map::Tube::London::Line::Jubilee::VERSION   = '0.50';
 $Map::Tube::London::Line::Jubilee::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Jubilee - London Tube Map Jubilee Line stations.
 
 =head1 VERSION
 
-Version 0.49
+Version 0.50
 
 =head1 DESCRIPTION
 
@@ -79,14 +79,14 @@ London Tube Map Jubilee Line stations.
 
 =head1 MAP
 
-London Metro: L<Jubilee|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Jubilee.png>
-line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Tube Map: L<Jubilee Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Jubilee.png>
+map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
 <a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Jubilee.png">
 <img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Jubilee.png"
-     alt    = "London Metro: Jubilee"
+     alt    = "London Tube Map: Jubilee Line"
      width  = "600px"
      height = "400px"/>
 </a>
