@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Metropolitan;
 
-$Map::Tube::London::Line::Metropolitan::VERSION   = '0.49';
+$Map::Tube::London::Line::Metropolitan::VERSION   = '0.50';
 $Map::Tube::London::Line::Metropolitan::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Metropolitan - London Tube Map Metropolitan Line statio
 
 =head1 VERSION
 
-Version 0.49
+Version 0.50
 
 =head1 DESCRIPTION
 
@@ -81,14 +81,14 @@ London Tube Map Metropolitan Line stations.
 
 =head1 MAP
 
-London Metro: L<Metropoiltan|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Metropolitan.png>
-line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Tube Map: L<Metropoiltan Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Metropolitan.png>
+map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
 <a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Metropolitan.png">
 <img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Metropolitan.png"
-     alt    = "London Metro: Metropolitan"
+     alt    = "LondonM Tube Map: Metropolitan Line"
      width  = "500px"
      height = "500px"/>
 </a>
