@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Northern;
 
-$Map::Tube::London::Line::Northern::VERSION   = '0.49';
+$Map::Tube::London::Line::Northern::VERSION   = '0.50';
 $Map::Tube::London::Line::Northern::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::London::Line::Northern - London Tube Map Northern Line stations.
 
 =head1 VERSION
 
-Version 0.49
+Version 0.50
 
 =head1 DESCRIPTION
 
@@ -87,8 +87,9 @@ London Tube Map Northern Line stations.
     | Old Street               | Angel, Moorgate                       |
     | Moorgate                 | Old Street, Bank                      |
     | Bank                     | Moorgate, London Bridge               |
-    | London Bridge            | Bank, Elephant and Castle             |
-    | Elephant and Castle      | London Bridge                         |
+    | London Bridge            | Bank, Borough                         |
+    | Borough                  | London Bridge, Elephant and Castle    |
+    | Elephant and Castle      | Borough                               |
     +--------------------------+---------------------------------------+
 
 =head2 Morden Branch
@@ -134,16 +135,16 @@ London Tube Map Northern Line stations.
 
 =head1 MAP
 
-London Metro: L<Northern|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Northern.png>
-line map generated by plugin L<Map::Tube::Plugin::Graph>.
+London Tube Map: L<Northern Line|https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Northern.png>
+map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
 <a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Northern.png">
 <img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-London/master/maps/Northern.png"
-     alt    = "London Metro: Nothern"
-     width  = "500px"
-     height = "500px"/>
+     alt    = "London Tube Metro: Northern Line"
+     width  = "400px"
+     height = "600px"/>
 </a>
 
 =end html
